#!/usr/bin/env python
###############################################################################
# $Id: colortable.py,v 1.1 2003/11/24 16:39:07 warmerda Exp $
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test functioning of the GDALColorTable.  Mostly this tests
#           the python binding. 
# Author:   Frank Warmerdam <warmerdam@pobox.com>
# 
###############################################################################
# Copyright (c) 2003, Frank Warmerdam <warmerdam@pobox.com>
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
###############################################################################
# 
#  $Log: colortable.py,v $
#  Revision 1.1  2003/11/24 16:39:07  warmerda
#  New
#
#

import os
import sys

sys.path.append( '../pymod' )

import gdaltest
import gdal

###############################################################################
# Create a color table.

def colortable_1():

    gdaltest.test_ct_data = [ (255,0,0), (0,255,0), (0,0,255), (255,255,255,0)]

    gdaltest.test_ct = gdal.ColorTable()
    for i in range(len(gdaltest.test_ct_data)):
        gdaltest.test_ct.SetColorEntry( i, gdaltest.test_ct_data[i] )

    return 'success' 

###############################################################################
# verify contents.

def colortable_2():

    for i in range(len(gdaltest.test_ct_data)):
        g_data = gdaltest.test_ct.GetColorEntry( i )
        o_data = gdaltest.test_ct_data[i]

        for j in range(4):
            if len(o_data) <= j:
                o_v = 255
            else:
                o_v = o_data[j]
                
            if g_data[j] != o_v:
                gdaltest.post_reason( 'color table mismatch' )
                return 'fail'

    return 'success' 

###############################################################################
# Cleanup.

def colortable_cleanup():
    gdaltest.test_ct = None
    return 'success'

gdaltest_list = [
    colortable_1,
    colortable_2,
    colortable_cleanup ]

if __name__ == '__main__':

    gdaltest.setup_run( 'colortable' )

    gdaltest.run_tests( gdaltest_list )

    gdaltest.summarize()

