#!/usr/bin/env python
###############################################################################
# $Id: minixml.py,v 1.1 2005/08/08 15:55:17 fwarmerdam Exp $
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test Minixml services from Python.
# Author:   Frank Warmerdam <warmerdam@pobox.com>
# 
###############################################################################
# Copyright (c) 2005, Frank Warmerdam <warmerdam@pobox.com>
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
###############################################################################
# 
#  $Log: minixml.py,v $
#  Revision 1.1  2005/08/08 15:55:17  fwarmerdam
#  New
#
#

import os
import sys
import string

sys.path.append( '../pymod' )

import gdaltest
import gdal

###############################################################################
# Parse a simple document into a tree of lists.

def minixml_1():

    tree = gdal.ParseXMLString( '<TestDoc style="123"><sub1/><sub2>abc</sub2></TestDoc>' )

    if tree[0] != gdal.CXT_Element:
        gdaltest.post_reason( 'wrong node type.' )
        return 'fail'

    if tree[1] != 'TestDoc':
        gdaltest.post_reason( 'Wrong element name' )
        return 'fail'

    if len(tree) != 5:
        gdaltest.post_reason( 'Wrong number of children.' )
        return 'fail'

    # Check style attribute
    node = tree[2]
    
    if node[0] != gdal.CXT_Attribute:
        gdaltest.post_reason( 'wrong node type.' )
        return 'fail'

    if node[1] != 'style':
        gdaltest.post_reason( 'Wrong element name' )
        return 'fail'

    if len(node) != 3:
        gdaltest.post_reason( 'Wrong number of children.' )
        return 'fail'

    if node[2][1] != '123':
        gdaltest.post_reason( 'Wrong element content.' )
        return 'fail'

    # Check <sub1> element
    node = tree[3]
    
    if node[0] != gdal.CXT_Element:
        gdaltest.post_reason( 'wrong node type.' )
        return 'fail'

    if node[1] != 'sub1':
        gdaltest.post_reason( 'Wrong element name' )
        return 'fail'

    if len(node) != 2:
        gdaltest.post_reason( 'Wrong number of children.' )
        return 'fail'

    # Check <sub2> element
    node = tree[4]
    
    if node[0] != gdal.CXT_Element:
        gdaltest.post_reason( 'wrong node type.' )
        return 'fail'

    if node[1] != 'sub2':
        gdaltest.post_reason( 'Wrong element name' )
        return 'fail'

    if len(node) != 3:
        gdaltest.post_reason( 'Wrong number of children.' )
        return 'fail'

    if node[2][1] != 'abc':
        gdaltest.post_reason( 'Wrong element content.' )
        return 'fail'

    return 'success' 

###############################################################################
# Serialize an XML Tree

def minixml_2():

    tree = [0,'TestDoc',[2,'style',[1,'123']],[0,'sub1'],[0,'sub2',[1,'abc']]]
    doc_target = '<TestDoc style="123">\n  <sub1/>\n  <sub2>abc</sub2>\n</TestDoc>\n'
    doc_got = gdal.SerializeXMLTree( tree )
    if doc_got != doc_target:
        gdaltest.post_reason( 'serialize xml tree failed.' )
        print doc_got
        return 'fail'
    return 'success' 

###############################################################################
# Cleanup

def minixml_cleanup():
    return 'success'

gdaltest_list = [
    minixml_1,
    minixml_2,
    minixml_cleanup ]

if __name__ == '__main__':

    gdaltest.setup_run( 'minixml' )
    gdaltest.run_tests( gdaltest_list )

    gdaltest.summarize()

