#!/usr/bin/env python
###############################################################################
# $Id: tiff_ovr.py,v 1.1 2004/11/11 05:51:57 fwarmerdam Exp $
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test Overview Support (mostly a GeoTIFF issue).
# Author:   Frank Warmerdam <warmerdam@pobox.com>
# 
###############################################################################
# Copyright (c) 2004, Frank Warmerdam <warmerdam@pobox.com>
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
###############################################################################
# 
#  $Log: tiff_ovr.py,v $
#  Revision 1.1  2004/11/11 05:51:57  fwarmerdam
#  New
#
#
#

import os
import sys
import gdal

sys.path.append( '../pymod' )

import gdaltest

###############################################################################
# Create a 3 band floating point GeoTIFF file so we can build overviews on it
# later.  Build overviews on it. 

def tiff_ovr_1():

    gdaltest.tiff_drv = gdal.GetDriverByName( 'GTiff' )

    src_ds = gdal.Open('data/mfloat32.vrt')
    gdaltest.tiff_drv.CreateCopy( 'tmp/mfloat32.tif', src_ds )
    src_ds = None

    ds = gdal.Open( 'tmp/mfloat32.tif' )
    err = ds.BuildOverviews( overviewlist = [2, 4] )

    if err != 0:
        gdaltest.post_reason('BuildOverviews reports an error' )
        return 'fail'

    if ds.GetRasterBand(1).GetOverviewCount() != 2:
        gdaltest.post_reason('Overview missing on target file.')
        return 'fail'

    ds = None

    return 'success'

###############################################################################
# Open file and verify some characteristics of the overviews. 

def tiff_ovr_2():

    src_ds = gdal.Open( 'tmp/mfloat32.tif' )

    if src_ds.GetRasterBand(2).GetOverviewCount() != 2:
        gdaltest.post_reason( 'overviews missing after re-open?' )
        return 'fail'

    ovr_band = src_ds.GetRasterBand(3).GetOverview(0)
    if ovr_band.XSize != 10 or ovr_band.YSize != 10:
        gdaltest.post_reason('first overview wrong size.')
        return 'fail'

    if ovr_band.Checksum() != 1087:
        print ovr_band.Checksum()
        gdaltest.post_reason( 'first overview wrong checkum' )
        return 'fail'

    ovr_band = src_ds.GetRasterBand(3).GetOverview(1)
    if ovr_band.XSize != 5 or ovr_band.YSize != 5:
        gdaltest.post_reason('first overview wrong size.')
        return 'fail'

    if ovr_band.Checksum() != 328:
        print ovr_band.Checksum()
        gdaltest.post_reason( 'first overview wrong checkum' )
        return 'fail'

    src_ds = None

    return 'success'

###############################################################################
# Open target file in update mode, and create internal overviews.

def tiff_ovr_3():

    os.unlink( 'tmp/mfloat32.tif.ovr' )
    
    src_ds = gdal.Open( 'tmp/mfloat32.tif', gdal.GA_Update )

    err = src_ds.BuildOverviews( overviewlist = [2, 4] )
    if err != 0:
        gdaltest.post_reason('BuildOverviews reports an error' )
        return 'fail'

    if src_ds.GetRasterBand(2).GetOverviewCount() != 2:
        gdaltest.post_reason( 'overviews missing after re-open?' )
        return 'fail'

    ovr_band = src_ds.GetRasterBand(3).GetOverview(0)
    if ovr_band.XSize != 10 or ovr_band.YSize != 10:
        gdaltest.post_reason('first overview wrong size.')
        return 'fail'

    if ovr_band.Checksum() != 1087:
        print ovr_band.Checksum()
        gdaltest.post_reason( 'first overview wrong checkum' )
        return 'fail'

    ovr_band = src_ds.GetRasterBand(3).GetOverview(1)
    if ovr_band.XSize != 5 or ovr_band.YSize != 5:
        gdaltest.post_reason('first overview wrong size.')
        return 'fail'

    if ovr_band.Checksum() != 328:
        print ovr_band.Checksum()
        gdaltest.post_reason( 'first overview wrong checkum' )
        return 'fail'

    src_ds = None

    return 'success'



###############################################################################
# Cleanup

def tiff_ovr_cleanup():
    gdaltest.tiff_drv.Delete( 'tmp/mfloat32.tif' )
    gdaltest.tiff_drv = None

    return 'success'

gdaltest_list = [
    tiff_ovr_1,
    tiff_ovr_2,
    tiff_ovr_3,
    tiff_ovr_cleanup ]

if __name__ == '__main__':

    gdaltest.setup_run( 'tiff_ovr' )

    gdaltest.run_tests( gdaltest_list )

    gdaltest.summarize()

