#!/usr/bin/env python
###############################################################################
# $Id: mem.py,v 1.1 2005/03/08 16:30:44 fwarmerdam Exp $
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test MEM format driver.
# Author:   Frank Warmerdam <warmerdam@pobox.com>
# 
###############################################################################
# Copyright (c) 2005, Frank Warmerdam <warmerdam@pobox.com>
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
###############################################################################
# 
#  $Log: mem.py,v $
#  Revision 1.1  2005/03/08 16:30:44  fwarmerdam
#  New
#
#

import os
import sys
import gdal
import array
import string

sys.path.append( '../pymod' )

import gdaltest

#
# TODO:
# o Add testing of add band.

###############################################################################
# Create a MEM dataset, and set some data, then test it.

def mem_1():

    #######################################################
    # Setup dataset
    drv = gdal.GetDriverByName('MEM')
    gdaltest.mem_ds = drv.Create( 'mem_1.mem', 50, 3, gdal.GDT_Int32, 1 )
    ds = gdaltest.mem_ds

    raw_data = array.array('f',range(150)).tostring()
    ds.WriteRaster( 0, 0, 50, 3, raw_data,
                    buf_type = gdal.GDT_Float32,
                    band_list = [1] )

    wkt = gdaltest.user_srs_to_wkt( 'EPSG:26711' )
    ds.SetProjection( wkt )

    gt = ( 440720, 5, 0, 3751320, 0, -5 )
    ds.SetGeoTransform( gt )

    band = ds.GetRasterBand(1)
    band.SetNoDataValue( -1.0 )

    #######################################################
    # Verify dataset.

    if band.GetNoDataValue() != -1.0:
        gdaltest.post_reason( 'no data is wrong' )
        return 'fail'

    if ds.GetProjection() != wkt:
        gdaltest.post_reason( 'projection wrong' )
        return 'fail'

    if ds.GetGeoTransform() != gt:
        gdaltest.post_reason( 'geotransform wrong' )
        return 'fail'

    if band.Checksum() != 1531:
        gdaltest.post_reason( 'checksum wrong' )
        print band.Checksum()
        return 'fail'

    gdaltest.mem_ds = None

    return 'success'

###############################################################################
# Open an in-memory array. 

def mem_2():

    # allocate band data array.

    p = gdal.ptrcreate( 'float', 5, 150 )
    tokens = string.split(p,'_')

    # build ds name.
    dsname = 'MEM:::DATAPOINTER=0x'+tokens[1]+',PIXELS=50,LINES=3,BANDS=1,' \
             + 'DATATYPE=Float32,PIXELOFFSET=4,LINEOFFSET=200,BANDOFFSET=0'

    ds = gdal.Open( dsname )
    if ds is None:
        gdaltest.post_reason( 'opening MEM dataset failed.' )
        return 'fail'

    chksum = ds.GetRasterBand(1).Checksum()
    if chksum != 750:
        gdaltest.post_reason( 'checksum failed.' )
        print chksum
        return 'fail'

    ds.GetRasterBand(1).Fill( 100.0 )
    ds.FlushCache()

    if gdal.ptrvalue(p,5) != 100.0:
        print gdal.ptrvalue(p,5)
        gdaltest.post_reason( 'fill seems to have failed.' )
        return 'fail'

    ds = None

    gdal.ptrfree( p )

    return 'success'


###############################################################################
# cleanup

def mem_cleanup():
    gdaltest.mem_ds = None
    return 'success'


gdaltest_list = [
    mem_1,
    mem_2,
    mem_cleanup ]
  


if __name__ == '__main__':

    gdaltest.setup_run( 'mem' )

    gdaltest.run_tests( gdaltest_list )

    gdaltest.summarize()

