#!/usr/bin/env python
###############################################################################
# $Id: pcraster.py,v 1.1 2004/11/11 03:06:54 fwarmerdam Exp $
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test PCRaster driver support.
# Author:   Frank Warmerdam <warmerdam@pobox.com>
# 
###############################################################################
# Copyright (c) 2004, Frank Warmerdam <warmerdam@pobox.com>
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
###############################################################################
# 
#  $Log: pcraster.py,v $
#  Revision 1.1  2004/11/11 03:06:54  fwarmerdam
#  New
#
#

import os
import sys
import gdal

sys.path.append( '../pymod' )

import gdaltest

###############################################################################
# Perform simple read test.

def pcraster_1():

    gdaltest.pcraster_drv = gdal.GetDriverByName( 'PCRaster' )

    if gdaltest.pcraster_drv is None:
        return 'skip'

    tst = gdaltest.GDALTest( 'PNG', 'ldd.map', 1, 4528 )
    return tst.testOpen()

###############################################################################
# Verify some auxilary data. 

def pcraster_2():

    if gdaltest.pcraster_drv is None:
        return 'skip'

    ds = gdal.Open( 'data/ldd.map' )

    gt = ds.GetGeoTransform()

    if gt[0] != 182140.0 or gt[1] != 10 or gt[2] != 0 \
       or gt[3] != 327880.0 or gt[4] != 0 or gt[5] != -10:
        gdal.post_reason( 'PCRaster geotransform wrong.' )
        return 'fail'

    band1 = ds.GetRasterBand(1)
    if band1.GetNoDataValue() != 255:
        gdal.post_reason( 'PCRaster NODATA value wrong or missing.' )
        return 'fail'

    return 'success'

    
gdaltest_list = [
    pcraster_1,
    pcraster_2 ]


if __name__ == '__main__':

    gdaltest.setup_run( 'pcraster' )

    gdaltest.run_tests( gdaltest_list )

    gdaltest.summarize()

