#!/usr/bin/env python
###############################################################################
# $Id: osr_ct.py,v 1.2 2003/11/10 17:07:58 warmerda Exp $
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test coordinate transformations. 
# Author:   Frank Warmerdam <warmerdam@pobox.com>
# 
###############################################################################
# Copyright (c) 2003, Frank Warmerdam <warmerdam@pobox.com>
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
###############################################################################
# 
#  $Log: osr_ct.py,v $
#  Revision 1.2  2003/11/10 17:07:58  warmerda
#  improve 3rd test check and comments
#
#  Revision 1.1  2003/11/10 17:01:24  warmerda
#  New
#
#

import os
import sys
import string

sys.path.append( '../pymod' )

import gdal
import gdaltest
import osr
import ogr


###############################################################################
# Verify that we have PROJ.4 available. 

def osr_ct_1():

    
    gdaltest.have_proj4 = 0
    
    utm_srs = osr.SpatialReference()
    utm_srs.SetUTM( 11 )
    utm_srs.SetWellKnownGeogCS( 'WGS84' )

    ll_srs = osr.SpatialReference()
    ll_srs.SetWellKnownGeogCS( 'WGS84' )

    gdal.PushErrorHandler( 'CPLQuietErrorHandler' )
    try:
        ct = osr.CoordinateTransformation( ll_srs, utm_srs )
    except ValueError, (err_msg):
        gdal.PopErrorHandler()
        if string.find(str(err_msg),'Unable to load PROJ.4') != -1:
            gdaltest.post_reason( 'PROJ.4 missing, transforms not available.' )
            return 'skip'
        else:
            gdaltest.post_reason( str(err_msg) )
            return 'fail'

    gdal.PopErrorHandler()
    if ct is None:
        gdaltest.post_reason( 'Unable to create simple CoordinateTransformat.')
        return 'fail'

    gdaltest.have_proj4 = 1

    return 'success'

###############################################################################
# Actually perform a simple LL to UTM conversion. 

def osr_ct_2():

    if gdaltest.have_proj4 == 0:
        return 'skip'

    utm_srs = osr.SpatialReference()
    utm_srs.SetUTM( 11 )
    utm_srs.SetWellKnownGeogCS( 'WGS84' )

    ll_srs = osr.SpatialReference()
    ll_srs.SetWellKnownGeogCS( 'WGS84' )

    gdaltest.ct = osr.CoordinateTransformation( ll_srs, utm_srs )

    result = gdaltest.ct.TransformPoint( -117.5, 32.0, 0.0 )
    if abs(result[0] - 452772.06) > 0.01 \
       or abs(result[1] - 3540544.89 ) > 0.01 \
       or abs(result[2] - 0.0) > 0.01:
        gdaltest.post_reason( 'Wrong LL to UTM result' )
        return 'fail'
    else:
        return 'success'

###############################################################################
# Transform an OGR geometry ... this is mostly aimed at ensuring that
# the OGRCoordinateTransformation target SRS isn't deleted till the output
# geometry which also uses it is deleted.

def osr_ct_3():

    if gdaltest.have_proj4 == 0:
        return 'skip'

    utm_srs = osr.SpatialReference()
    utm_srs.SetUTM( 11 )
    utm_srs.SetWellKnownGeogCS( 'WGS84' )

    ll_srs = osr.SpatialReference()
    ll_srs.SetWellKnownGeogCS( 'WGS84' )

    ct = osr.CoordinateTransformation( ll_srs, utm_srs )

    pnt = ogr.CreateGeometryFromWkt( 'POINT(-117.5 32.0)', ll_srs )
    result = pnt.Transform( ct )

    ll_srs = None
    ct = None
    utm_srs = None

    out_srs = pnt.GetSpatialReference().ExportToPrettyWkt()
    if out_srs[0:6] != 'PROJCS':
        gdaltest.post_reason( 'output srs corrupt, ref counting issue?' )
        return 'fail'

    pnt = None

    return 'success'
    
    
###############################################################################
# Cleanup

def osr_ct_cleanup():

    if gdaltest.have_proj4 == 0:
        return 'skip'

    gdaltest.ct = None

    return 'success'

gdaltest_list = [ 
    osr_ct_1,
    osr_ct_2,
    osr_ct_3,
    osr_ct_cleanup,
    None ]

if __name__ == '__main__':

    gdaltest.setup_run( 'osr_ct' )

    gdaltest.run_tests( gdaltest_list )

    gdaltest.summarize()

