#!/usr/bin/env ruby

# Datasources own layers and thus must not be freed while a
# layer is still referenced.  These tests verify this.

require 'test/unit'
require 'gdal/ogr'
require 'ogrtest'


class TestMemoryDataSource < Test::Unit::TestCase
	def open_ds
	  # Get the pat to the file
	  file_name = File.join(data_directory, 'poly.shp')

	  # Open datasource in update mode
		return Ogr.open(file_name, 1)
	end   

	def test_ds_owns_layer
	  # Try to free a datasource before a layer.  If that happens
	  # then a GPF will occur
	  begin
	    ds = open_ds
	    layer = ds.get_layer(0)
	    ds = nil
		end

		GC.start

		assert_equal(10, layer.get_feature_count)
	end

	def test_ds_copy_layer
	  # Try to free a datasource before a layer.  If that happens
	  # then a GPF will occur
	  begin
	    ds = open_ds
	    layer = ds.get_layer(0)
	    
	    # This will create a new layer in the data directory
	    layer_copy = ds.copy_layer(layer, '../temp_copy.shp')
	    
	    layer = nil
	    ds = nil
		end

		GC.start

		assert_equal(10, layer_copy.get_feature_count)
	end

	def test_ds_create_layer
	  begin
	    ds = open_ds
	    layer = ds.get_layer(0)
	    
	    # Create a new layer in the data directory
	    new_layer = ds.create_layer('../temp_new.shp')
	    
	    layer = nil
	    ds = nil
		end

		GC.start

		assert_equal(0, new_layer.get_feature_count)
	end
end
